@@ -1,29 +1,25 @@
-import logging
-import time
 import socket
-from datetime import datetime
+import logging
 from flumelogger.eventserver import FlumeEventServer
 
 class FlumeHandler(logging.Handler):
-    def __init__(self, host="localhost", port=9090, src_host=None, fields={}):
+    def __init__(self, host="localhost", port=9090, headers={}):
         # run the regular Handler __init__
         logging.Handler.__init__(self)
 
         self.host = host
         self.port = port
-        self.src_host = src_host
-        if not self.src_host:
-            self.src_host = socket.gethostname()
-        self.fields = fields
+        self.headers = headers
+        if not self.headers.has_key('source_host'):
+            self.headers['source_host'] = socket.gethostname()
 
     def emit(self, record):
         try:
             evt = FlumeEventServer(host=self.host, port=self.port)
-            pri = FlumeEventServer.PRIORITY[record.levelname.upper()]
-            dt = int(time.time() * 1000)
-            ns = datetime.now().microsecond * 1000
+            self.headers['pri'] = record.levelname.upper()
             # record is the log message
-            evt.append(pri, self.format(record), self.src_host, dt, ns, fields=self.fields)
+            evt.append(self.headers, self.format(record))
+            evt.close()
         except (KeyboardInterrupt, SystemExit):
             raise
         except:
